==> nvidia_nsys_cli-2020.4.1.126-py3-none-linux_x86_64.whl: nsys_cli_pycli_wrapper/package_info.py <==
#! /usr/bin/python
# -*- coding: utf-8 -*-

# Copyright 2009-2016  NVIDIA Corporation.  All rights reserved.
#
# NOTICE TO USER:
#
# This source code is subject to NVIDIA ownership rights under U.S. and
# international Copyright laws.
#
# This software and the information contained herein is PROPRIETARY and
# CONFIDENTIAL to NVIDIA and is being provided under the terms and conditions
# of a form of NVIDIA software license agreement.
#
# NVIDIA MAKES NO REPRESENTATION ABOUT THE SUITABILITY OF THIS SOURCE
# CODE FOR ANY PURPOSE.  IT IS PROVIDED "AS IS" WITHOUT EXPRESS OR
# IMPLIED WARRANTY OF ANY KIND.  NVIDIA DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS SOURCE CODE, INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
# IN NO EVENT SHALL NVIDIA BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL,
# OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
# OF USE, DATA OR PROFITS,  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
# OR OTHER TORTIOUS ACTION,  ARISING OUT OF OR IN CONNECTION WITH THE USE
# OR PERFORMANCE OF THIS SOURCE CODE.
#
# U.S. Government End Users.   This source code is a "commercial item" as
# that term is defined at  48 C.F.R. 2.101 (OCT 1995), consisting  of
# "commercial computer  software"  and "commercial computer software
# documentation" as such terms are  used in 48 C.F.R. 12.212 (SEPT 1995)
# and is provided to the U.S. Government only as a commercial end item.
# Consistent with 48 C.F.R.12.212 and 48 C.F.R. 227.7202-1 through
# 227.7202-4 (JUNE 1995), all U.S. Government End Users acquire the
# source code with only those rights set forth herein.
#
# Any use of this source code in individual and commercial software must
# include, in the user documentation and internal comments to the code,
# the above Disclaimer and U.S. Government End Users Notice.

# Use the following formatting: (major, minor, patch, prerelease)

__shortversion__ = '2020.4.1.126'
__version__ = '2020.4.1.126'

__package_name__ = 'nvidia-nsys-cli'
__contact_names__ = 'Nsight Systems team'
__contact_emails__ = 'nsight-systems@nvidia.com'
__homepage__ = 'https://developer.nvidia.com/nsight-systems'
__repository_url__ = 'https://developer.nvidia.com/nsight-systems'
__download_url__ = 'https://developer.nvidia.com/nsight-systems'
__description__ = 'NVIDIA Nsight Systems is a system-wide performance analysis tool designed to visualize an application’s algorithms, help you identify the largest opportunities to optimize, and tune to scale efficiently across any quantity or size of CPUs and GPUs; from large server to our smallest SoC'
__license__ = 'NVIDIA Software License'
__keywords__ = 'NVIDIA, deep learning, machine learning, supervised ' \
               'learning, unsupervised learning, reinforcement learning, ' \
               'profiling, nsys, nsight, GPU, CUDA'

==> nvidia_nsys_cli-2020.5.1.83-py3-none-linux_x86_64.whl: nsys_cli_pycli_wrapper/package_info.py <==
#! /usr/bin/python
# -*- coding: utf-8 -*-

# Copyright 2009-2016  NVIDIA Corporation.  All rights reserved.
#
# NOTICE TO USER:
#
# This source code is subject to NVIDIA ownership rights under U.S. and
# international Copyright laws.
#
# This software and the information contained herein is PROPRIETARY and
# CONFIDENTIAL to NVIDIA and is being provided under the terms and conditions
# of a form of NVIDIA software license agreement.
#
# NVIDIA MAKES NO REPRESENTATION ABOUT THE SUITABILITY OF THIS SOURCE
# CODE FOR ANY PURPOSE.  IT IS PROVIDED "AS IS" WITHOUT EXPRESS OR
# IMPLIED WARRANTY OF ANY KIND.  NVIDIA DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS SOURCE CODE, INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
# IN NO EVENT SHALL NVIDIA BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL,
# OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
# OF USE, DATA OR PROFITS,  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
# OR OTHER TORTIOUS ACTION,  ARISING OUT OF OR IN CONNECTION WITH THE USE
# OR PERFORMANCE OF THIS SOURCE CODE.
#
# U.S. Government End Users.   This source code is a "commercial item" as
# that term is defined at  48 C.F.R. 2.101 (OCT 1995), consisting  of
# "commercial computer  software"  and "commercial computer software
# documentation" as such terms are  used in 48 C.F.R. 12.212 (SEPT 1995)
# and is provided to the U.S. Government only as a commercial end item.
# Consistent with 48 C.F.R.12.212 and 48 C.F.R. 227.7202-1 through
# 227.7202-4 (JUNE 1995), all U.S. Government End Users acquire the
# source code with only those rights set forth herein.
#
# Any use of this source code in individual and commercial software must
# include, in the user documentation and internal comments to the code,
# the above Disclaimer and U.S. Government End Users Notice.

MAJOR = 2020
MINOR = 5
PATCH = 1
PRE_RELEASE = '83'
# Use the following formatting: (major, minor, patch, prerelease)
VERSION = (MAJOR, MINOR, PATCH, PRE_RELEASE)

__shortversion__ = '.'.join(map(str, VERSION[:3]))
__version__ = '.'.join(map(str, VERSION))

__package_name__ = 'nvidia-nsys-cli'
__contact_names__ = 'Nsight Systems team'
__contact_emails__ = 'nsight-systems@nvidia.com'
__homepage__ = 'https://developer.nvidia.com/nsight-systems'
__repository_url__ = 'https://developer.nvidia.com/nsight-systems'
__download_url__ = 'https://developer.nvidia.com/nsight-systems'
__description__ = 'NVIDIA Nsight Systems is a system-wide performance analysis tool designed to visualize an application’s algorithms, help you identify the largest opportunities to optimize, and tune to scale efficiently across any quantity or size of CPUs and GPUs; from large server to our smallest SoC'
__license__ = 'NVIDIA Software License'
__keywords__ = 'NVIDIA, deep learning, machine learning, supervised ' \
               'learning, unsupervised learning, reinforcement learning, ' \
               'profiling, nsys, nsight, GPU, CUDA'
